@@ -24,7 +24,7 @@ import traceback
 from threading import Thread
 import logging
 
-import ftputil
+# import ftputil
 from secure_delete import secure_delete
 import colemen_string_utils as strUtils
 import utils.dir as directory
